float_column library
Classes
- Floatable
- A floatable widget.
- FloatColumn
-
A vertical column of widgets and text with the ability to "float" child
widgets to the left or right, allowing the text to wrap around them —
similar to the functionality of the CSS
floatandclearproperties. - FloatColumnChildManager
- FloatColumnParentData
- Parent data for use with RenderFloatColumn.
- RenderFloatColumn
- Displays its children in a vertical column.
- RenderParagraphAdapter
- Adapts a RenderParagraph to support RenderTextMixin.
- SplitAtIndex
- Mutable wrapper of an integer index that can be passed by reference.
- SplittableString
- An example of a class that adopts the SplittableMixin -- a splittable string.
- WrappableText
-
An immutable span of inline content which forms a paragraph. Only useful as
a child of a
FloatColumn, which provides the capability of wrapping the paragraph around child widgets that "float" to the right or left.
Mixins
- RenderTextMixin
- Mix this into classes that should mirror the functionality of RenderParagraph.
-
SplittableMixin<
T> - Mix this in with a class that can be split at an integer index.
- VisitChildrenOfAnyTypeMixin
-
Mix this into classes that should implement
visitChildrenOfAnyType.
Extensions
- FCInlineSpanExt on InlineSpan
-
FCListOfInlineSpanExt
on List<
InlineSpan> - FCTextSpanExt on TextSpan
- FloatColumnExtOnRenderObject on RenderObject
- Extensions on RenderObject.
Functions
-
valueOfFirstDescendantOf<
T, V> (T node, {required bool where(T), required V defaultValue, required V? getValue(T), required Iterable< T> ? childrenOf(T), bool isValueInherited = true}) → V? -
Walks the given
nodeand its descendants in pre-order and returns the value (usinggetValue) of the first node (including the initial node) where thewherefunction returnstrue. If no matching node is found,nullis returned.
Typedefs
- CancelableObjectVisitor = bool Function(Object child)
-
Signature for a function that takes an Object and returns
trueto continue, orfalseto cancel.